# Yosemite

### Documentation Available @ **[code.hammad.fun](https://code.hammad.fun)**

## Installing

### Install From PyPi

```bash
pip install -U yosemite
# pip install -U yosemite-tiny

yosemite
```

### Build from Source

```bash
git clone https://github.com/hsaeed3/yosemite

cd yosemite
pip install .

yosemite
```
